@@ -24,9 +24,12 @@ class Cli:
 
         self.flaxkv_server = self.sparrow_config.get("flaxkv_server", os.environ.get("FLAXKV_SERVER"))
         if self.flaxkv_server:
-            from flaxkv import FlaxKV
-            
-            self._db = FlaxKV(db_name="sparrow", root_path_or_url=self.flaxkv_server, show_progress=True)
+            try:
+                from flaxkv import FlaxKV
+                self._db = FlaxKV(db_name="sparrow", root_path_or_url=self.flaxkv_server, show_progress=True)
+            except Exception as e:
+                print(f"Error initializing FlaxKV: {e}")
+                self._db = None
         else:
             self._db = None
 
@@ -81,9 +84,9 @@ class Cli:
         raise NotImplementedError
 
     @staticmethod
-    def download(repo_id, download_dir=None, backend="huggingface", token=None):
+    def download(repo_id, download_dir=None, backend="huggingface", token=None, **kwargs):
         from .models.downloads import download_model
-        download_model(repo_id, download_dir=download_dir, backend=backend, token=token)
+        download_model(repo_id, download_dir=download_dir, backend=backend, token=token, **kwargs)
 
     @staticmethod
     def deduplicate(in_file: str, out_file: str, target_col='data', chunk_size = 200, threshold=None, method:Literal["edit", "rouge", "bleu"]='edit', use_jieba=False):
