@@ -152,17 +152,54 @@ class MetricsCalculator:
                     f"| {label} | {metrics['precision']:.2f} | {metrics['recall']:.2f} | {metrics['f1-score']:.2f} | {metrics['support']:.0f} |")
         return header + separator + "\n".join(rows)
 
-    def format_confusion_matrix_as_markdown(self):
+    def clean_label_for_markdown(self, label, max_length=20):
+        """清理标签文本，使其适合在markdown表格中显示"""
+        # 转换为字符串并替换换行符
+        label = str(label).replace('\n', ' ')
+        
+        # 移除或替换可能破坏markdown格式的字符
+        label = label.replace("|", "\\|")
+        label = label.replace("-", "\\-")
+        label = label.replace("<", "&lt;")
+        label = label.replace(">", "&gt;")
+        
+        # 截断长文本
+        if len(label) > max_length:
+            label = label[:max_length] + "..."
+            
+        # 确保标签至少有一个可见字符
+        label = label.strip()
+        if not label:
+            label = "(empty)"
+            
+        return label
+
+    def format_confusion_matrix_as_markdown(self, max_label_length=20):
         matrix = self.metrics['confusion_matrix']
-        labels = self.all_labels
-        header = "| | " + " | ".join(labels) + " |\n"
-        separator = "|---" + "|---" * len(labels) + "|\n"
+        
+        # 处理标签
+        if self.remove_matrix_zero_row:
+            labels = self.needed_labels
+        else:
+            labels = self.all_labels
+            
+        # 处理所有标签
+        processed_labels = [self.clean_label_for_markdown(label, max_label_length) for label in labels]
+            
+        # 构建表头，确保第一列也有标题
+        header = "| 真实值/预测值 | " + " | ".join(processed_labels) + " |\n"
+        
+        # 修复分隔符，确保每列都有正确的分隔符
+        separator_parts = [":---:"] * (len(processed_labels) + 1)  # +1 是为了第一列
+        separator = "| " + " | ".join(separator_parts) + " |\n"
+        
         rows = []
         for i, row in enumerate(matrix):
-            if self.remove_matrix_zero_row:
-                rows.append(f"| {self.needed_labels[i]} | " + " | ".join(map(str, row)) + " |")
-            else:
-                rows.append(f"| {labels[i]} | " + " | ".join(map(str, row)) + " |")
+            # 处理行标签
+            row_label = self.clean_label_for_markdown(labels[i], max_label_length)
+            # 格式化数字
+            formatted_row = [f"{num:,}" for num in row]
+            rows.append(f"| {row_label} | " + " | ".join(formatted_row) + " |")
 
         return header + separator + "\n".join(rows)
 
