@@ -2,10 +2,14 @@ import asyncio
 import base64
 import os
 import hashlib
+import json
+import time
 from copy import deepcopy
 from io import BytesIO
 from mimetypes import guess_type
 from pathlib import Path
+from dataclasses import dataclass, field
+from typing import Optional
 
 import aiohttp
 import requests
@@ -23,6 +27,44 @@ except AttributeError:
 # 默认的缓存目录
 DEFAULT_CACHE_DIR = os.path.expanduser("~/.cache/sparrow/image_cache")
 
+@dataclass
+class ImageCacheConfig:
+    """图像缓存配置类，用于集中管理图像缓存的相关配置"""
+    enabled: bool = False  # 是否启用缓存
+    cache_dir: str = DEFAULT_CACHE_DIR  # 缓存目录路径
+    force_refresh: bool = False  # 是否强制刷新缓存
+    retry_failed: bool = False  # 是否重试已知失败的链接
+    
+    def __post_init__(self):
+        """初始化后执行的操作，确保缓存目录存在"""
+        if self.enabled:
+            ensure_cache_dir(self.cache_dir)
+    
+    @classmethod
+    def disabled(cls) -> 'ImageCacheConfig':
+        """快速创建一个禁用缓存的配置"""
+        return cls(enabled=False)
+    
+    @classmethod
+    def default(cls) -> 'ImageCacheConfig':
+        """创建默认配置（启用缓存但不强制刷新和重试失败）"""
+        return cls(enabled=True)
+    
+    @classmethod
+    def with_refresh(cls) -> 'ImageCacheConfig':
+        """创建启用缓存且强制刷新的配置"""
+        return cls(enabled=True, force_refresh=True)
+    
+    @classmethod
+    def with_retry(cls) -> 'ImageCacheConfig':
+        """创建启用缓存且重试失败链接的配置"""
+        return cls(enabled=True, retry_failed=True)
+    
+    @classmethod
+    def full_refresh(cls) -> 'ImageCacheConfig':
+        """创建启用缓存且同时强制刷新和重试失败的配置"""
+        return cls(enabled=True, force_refresh=True, retry_failed=True)
+
 def get_cache_path(url: str, cache_dir: str = DEFAULT_CACHE_DIR) -> Path:
     """获取图片的缓存路径"""
     # 使用URL的MD5作为文件名
@@ -33,6 +75,12 @@ def get_cache_path(url: str, cache_dir: str = DEFAULT_CACHE_DIR) -> Path:
         ext = '.png'  # 默认使用.png 而不是 .jpg，因为 PNG 支持透明通道
     return Path(cache_dir) / f"{url_hash}{ext}"
 
+def get_error_cache_path(url: str, cache_dir: str = DEFAULT_CACHE_DIR) -> Path:
+    """获取图片请求错误的缓存文件路径"""
+    # 使用URL的MD5作为文件名，但添加.error后缀
+    url_hash = hashlib.md5(url.encode()).hexdigest()
+    return Path(cache_dir) / f"{url_hash}.error"
+
 def ensure_cache_dir(cache_dir: str = DEFAULT_CACHE_DIR):
     """确保缓存目录存在"""
     os.makedirs(cache_dir, exist_ok=True)
@@ -88,6 +136,7 @@ async def encode_to_base64(
     session: aiohttp.ClientSession,
     return_with_mime: bool = True,
     return_pil: bool = False,
+    cache_config: Optional[ImageCacheConfig] = None,
 ) -> str | tuple[str, Image.Image] | Image.Image:
     """A unified function to encode files to Base64 strings or return PIL Image objects.
 
@@ -96,6 +145,7 @@ async def encode_to_base64(
         session: aiohttp ClientSession for async URL fetching
         return_with_mime: Whether to include MIME type prefix in base64 string
         return_pil: Whether to return PIL Image object (for image files)
+        cache_config: Image cache configuration, if None or disabled, no caching will be used
 
     Returns:
         If return_pil is False: base64 string (with optional MIME prefix)
@@ -128,16 +178,27 @@ async def encode_to_base64(
                 content = file.read()
 
         elif file_source.startswith("http"):
-            async with session.get(file_source) as response:
-                response.raise_for_status()
-                content = await response.read()
-                mime_type = response.headers.get(
-                    "Content-Type", "application/octet-stream"
-                )
-                if return_pil and mime_type.startswith("image"):
-                    pil_image = Image.open(BytesIO(content))
-                    if return_pil and not return_with_mime:
-                        return pil_image
+            # 对于URL，使用get_pil_image来获取图像，以利用缓存功能
+            if return_pil or mime_type and mime_type.startswith("image"):
+                # 获取PIL图像并利用缓存
+                pil_image = await get_pil_image(file_source, session, cache_config=cache_config)
+                if return_pil and not return_with_mime:
+                    return pil_image
+                    
+                # 将PIL图像转换为字节内容
+                buffer = BytesIO()
+                image_format = pil_image.format or "PNG"
+                mime_type = f"image/{image_format.lower()}"
+                pil_image.save(buffer, format=image_format)
+                content = buffer.getvalue()
+            else:
+                # 对于非图像文件，直接从URL获取内容
+                async with session.get(file_source) as response:
+                    response.raise_for_status()
+                    content = await response.read()
+                    mime_type = response.headers.get(
+                        "Content-Type", "application/octet-stream"
+                    )
         else:
             raise ValueError("Unsupported file source type.")
 
@@ -172,9 +233,7 @@ async def encode_image_to_base64(
     max_height: int | None = None,
     max_pixels: int | None = None,
     return_with_mime: bool = True,
-    use_cache: bool = False,
-    cache_dir: str = DEFAULT_CACHE_DIR,
-    force_refresh: bool = False
+    cache_config: Optional[ImageCacheConfig] = None
 ) -> str:
     """Encode an image to base64 string with optional size constraints.
 
@@ -185,9 +244,7 @@ async def encode_image_to_base64(
         max_height: Optional maximum height for image resizing
         max_pixels: Optional maximum number of pixels (width * height)
         return_with_mime: Whether to include MIME type prefix in the result
-        use_cache: Whether to use cache for URL images
-        cache_dir: Cache directory path
-        force_refresh: Whether to force refresh the cache even if cached image exists
+        cache_config: Image cache configuration, if None or disabled, no caching will be used
 
     Returns:
         Base64 encoded string (with optional MIME prefix)
@@ -196,8 +253,13 @@ async def encode_image_to_base64(
     if isinstance(image_source, Image.Image):
         image = image_source
     else:
-        # Use encode_to_base64 with return_pil=True to get PIL Image directly
-        image = await get_pil_image(image_source, session, use_cache=use_cache, cache_dir=cache_dir, force_refresh=force_refresh)
+        # 使用更新后的get_pil_image函数，但不需要返回缓存路径
+        image = await get_pil_image(
+            image_source, 
+            session, 
+            cache_config=cache_config,
+            return_cache_path=False
+        )
 
     # Make a copy of the image to avoid modifying the original
     image = image.copy()
@@ -296,28 +358,32 @@ async def _get_image_from_http(session, image_source):
 async def get_pil_image(
     image_source,
     session: aiohttp.ClientSession = None,
-    use_cache: bool = False,
-    cache_dir: str = DEFAULT_CACHE_DIR,
-    force_refresh: bool = False
+    cache_config: Optional[ImageCacheConfig] = None,
+    return_cache_path: bool = False
 ):
     """从图像链接或本地路径获取PIL格式的图像。
 
     Args:
         image_source: 图像来源，可以是本地文件路径或URL
         session: 用于异步URL请求的aiohttp ClientSession，如果为None且需要时会创建临时会话
-        use_cache: 是否使用缓存（仅对URL图片有效）
-        cache_dir: 缓存目录路径
-        force_refresh: 是否强制刷新缓存，即使缓存存在也重新获取图像
+        cache_config: 图像缓存配置，如果为None则不使用缓存
+        return_cache_path: 是否同时返回图像和缓存路径，如果为True则返回(image, cache_path)元组
 
     Returns:
-        PIL.Image.Image: 加载的PIL图像对象
+        PIL.Image.Image 或 tuple[PIL.Image.Image, Path]: 
+            - 如果return_cache_path为False，返回加载的PIL图像对象
+            - 如果return_cache_path为True，返回(image, cache_path)元组，对于非URL图像或未使用缓存时，cache_path为None
 
     Raises:
         ValueError: 当图像源无效或无法加载图像时
     """
+    # 处理缓存配置
+    if cache_config is None:
+        cache_config = ImageCacheConfig.disabled()
+    
     # 如果已经是PIL图像对象，直接返回
     if isinstance(image_source, Image.Image):
-        return image_source
+        return (image_source, None) if return_cache_path else image_source
 
     # 处理字符串类型的图像源（文件路径或URL）
     if isinstance(image_source, str):
@@ -326,20 +392,39 @@ async def get_pil_image(
             file_path = image_source[7:]
             if not os.path.exists(file_path):
                 raise ValueError(f"本地文件不存在: {file_path}")
-            return Image.open(file_path)
+            image = Image.open(file_path)
+            return (image, Path(file_path)) if return_cache_path else image
             
         # 处理普通本地文件路径
         elif os.path.exists(image_source):
-            return Image.open(image_source)
+            image = Image.open(image_source)
+            return (image, Path(image_source)) if return_cache_path else image
             
         # 处理URL
         elif image_source.startswith("http"):
             # 检查缓存
-            if use_cache and not force_refresh:
-                ensure_cache_dir(cache_dir)
-                cache_path = get_cache_path(image_source, cache_dir)
-                if cache_path.exists():
-                    return Image.open(cache_path)
+            cache_path = None
+            error_cache_path = None
+            
+            if cache_config.enabled:
+                cache_path = get_cache_path(image_source, cache_config.cache_dir)
+                error_cache_path = get_error_cache_path(image_source, cache_config.cache_dir)
+                
+                # 检查普通缓存
+                if not cache_config.force_refresh and cache_path.exists():
+                    image = Image.open(cache_path)
+                    return (image, cache_path) if return_cache_path else image
+                
+                # 检查错误缓存
+                if not cache_config.force_refresh and not cache_config.retry_failed and error_cache_path.exists():
+                    try:
+                        with open(error_cache_path, 'r') as f:
+                            error_data = json.load(f)
+                        # 重新构造相同的错误
+                        raise ValueError(f"缓存的错误: {error_data['message']}")
+                    except (json.JSONDecodeError, KeyError):
+                        # 如果错误缓存文件格式不正确，忽略它
+                        logger.warning(f"错误缓存文件格式不正确: {error_cache_path}")
 
             # 创建临时会话（如果未提供）
             close_session = False
@@ -350,13 +435,32 @@ async def get_pil_image(
             try:
                 image = await _get_image_from_http(session, image_source)
                 # 保存到缓存
-                if use_cache:
+                if cache_config.enabled:
                     try:
                         save_image_with_format(image, cache_path)
+                        # 如果请求成功，删除可能存在的错误缓存
+                        if error_cache_path and error_cache_path.exists():
+                            error_cache_path.unlink()
                     except Exception as e:
                         logger.warning(f"保存图片到缓存失败: {e}")
                     
-                    return image
+                return (image, cache_path) if return_cache_path else image
+            except Exception as e:
+                # 缓存错误信息
+                if cache_config.enabled and error_cache_path:
+                    try:
+                        with open(error_cache_path, 'w') as f:
+                            error_data = {
+                                "url": image_source,
+                                "timestamp": time.time(),
+                                "message": str(e),
+                                "type": type(e).__name__
+                            }
+                            json.dump(error_data, f)
+                    except Exception as cache_err:
+                        logger.warning(f"缓存错误信息失败: {cache_err}")
+                # 重新抛出原始异常
+                raise
             finally:
                 # 如果是临时创建的会话，确保关闭
                 if close_session and session:
@@ -369,27 +473,31 @@ async def get_pil_image(
 
 def get_pil_image_sync(
     image_source,
-    use_cache: bool = False,
-    cache_dir: str = DEFAULT_CACHE_DIR,
-    force_refresh: bool = False
+    cache_config: Optional[ImageCacheConfig] = None,
+    return_cache_path: bool = False
 ):
     """从图像链接或本地路径获取PIL格式的图像（同步版本）。
 
     Args:
         image_source: 图像来源，可以是本地文件路径或URL
-        use_cache: 是否使用缓存（仅对URL图片有效）
-        cache_dir: 缓存目录路径
-        force_refresh: 是否强制刷新缓存，即使缓存存在也重新获取图像
+        cache_config: 图像缓存配置，如果为None则不使用缓存
+        return_cache_path: 是否同时返回图像和缓存路径，如果为True则返回(image, cache_path)元组
 
     Returns:
-        PIL.Image.Image: 加载的PIL图像对象
+        PIL.Image.Image 或 tuple[PIL.Image.Image, Path]: 
+            - 如果return_cache_path为False，返回加载的PIL图像对象
+            - 如果return_cache_path为True，返回(image, cache_path)元组，对于非URL图像或未使用缓存时，cache_path为None
 
     Raises:
         ValueError: 当图像源无效或无法加载图像时
     """
+    # 处理缓存配置
+    if cache_config is None:
+        cache_config = ImageCacheConfig.disabled()
+    
     # 如果已经是PIL图像对象，直接返回
     if isinstance(image_source, Image.Image):
-        return image_source
+        return (image_source, None) if return_cache_path else image_source
 
     # 处理字符串类型的图像源（文件路径或URL）
     if isinstance(image_source, str):
@@ -398,33 +506,72 @@ def get_pil_image_sync(
             file_path = image_source[7:]
             if not os.path.exists(file_path):
                 raise ValueError(f"本地文件不存在: {file_path}")
-            return Image.open(file_path)
+            image = Image.open(file_path)
+            return (image, Path(file_path)) if return_cache_path else image
             
         # 处理普通本地文件路径
         elif os.path.exists(image_source):
-            return Image.open(image_source)
+            image = Image.open(image_source)
+            return (image, Path(image_source)) if return_cache_path else image
             
         # 处理URL
         elif image_source.startswith("http"):
             # 检查缓存
-            if use_cache and not force_refresh:
-                ensure_cache_dir(cache_dir)
-                cache_path = get_cache_path(image_source, cache_dir)
-                if cache_path.exists():
-                    return Image.open(cache_path)
-                    
-            response = requests.get(image_source)
-            response.raise_for_status()
-            image = Image.open(BytesIO(response.content))
+            cache_path = None
+            error_cache_path = None
             
-            # 保存到缓存
-            if use_cache:
-                try:
-                    save_image_with_format(image, cache_path)
-                except Exception as e:
-                    logger.warning(f"保存图片到缓存失败: {e}")
+            if cache_config.enabled:
+                cache_path = get_cache_path(image_source, cache_config.cache_dir)
+                error_cache_path = get_error_cache_path(image_source, cache_config.cache_dir)
+                
+                # 检查普通缓存
+                if not cache_config.force_refresh and cache_path.exists():
+                    image = Image.open(cache_path)
+                    return (image, cache_path) if return_cache_path else image
+                
+                # 检查错误缓存
+                if not cache_config.force_refresh and not cache_config.retry_failed and error_cache_path.exists():
+                    try:
+                        with open(error_cache_path, 'r') as f:
+                            error_data = json.load(f)
+                        # 重新构造相同的错误
+                        raise ValueError(f"缓存的错误: {error_data['message']}")
+                    except (json.JSONDecodeError, KeyError):
+                        # 如果错误缓存文件格式不正确，忽略它
+                        logger.warning(f"错误缓存文件格式不正确: {error_cache_path}")
                     
-            return image
+            try:
+                response = requests.get(image_source)
+                response.raise_for_status()
+                image = Image.open(BytesIO(response.content))
+                
+                # 保存到缓存
+                if cache_config.enabled:
+                    try:
+                        save_image_with_format(image, cache_path)
+                        # 如果请求成功，删除可能存在的错误缓存
+                        if error_cache_path and error_cache_path.exists():
+                            error_cache_path.unlink()
+                    except Exception as e:
+                        logger.warning(f"保存图片到缓存失败: {e}")
+                        
+                return (image, cache_path) if return_cache_path else image
+            except Exception as e:
+                # 缓存错误信息
+                if cache_config.enabled and error_cache_path:
+                    try:
+                        with open(error_cache_path, 'w') as f:
+                            error_data = {
+                                "url": image_source,
+                                "timestamp": time.time(),
+                                "message": str(e),
+                                "type": type(e).__name__
+                            }
+                            json.dump(error_data, f)
+                    except Exception as cache_err:
+                        logger.warning(f"缓存错误信息失败: {cache_err}")
+                # 重新抛出原始异常
+                raise
         else:
             raise ValueError(f"不支持的图像源类型: {image_source}")
     else:
